@@ -16,6 +16,7 @@ from plone.restapi.serializer.converters import json_compatible
 from plone.restapi.serializer.expansion import expandable_elements
 from plone.restapi.serializer.nextprev import NextPrevious
 from plone.restapi.serializer.working_copy import WorkingCopyInfo
+from plone.restapi.services.locking import lock_info
 from plone.rfc822.interfaces import IPrimaryFieldInfo
 from plone.supermodel.utils import mergedTaggedValueDict
 from Products.CMFCore.utils import getToolByName
@@ -79,6 +80,9 @@ class SerializeToJson:
         baseline, working_copy = WorkingCopyInfo(self.context).get_working_copy_info()
         result.update({"working_copy": working_copy, "working_copy_of": baseline})
 
+        # Insert locking information
+        result.update({"lock": lock_info(obj)})
+
         # Insert expandable elements
         result.update(expandable_elements(self.context, self.request))
 
